from manifest_edit.plugin.manifest_iterators import (
    ManifestIterator as BaseManifestIterator,
)
from manifest_edit.plugin.manifest_iterators import FieldMatcher

from schema import Schema, Or, And, Optional
import re


def _is_config_dict_not_empty(data):
    return len(data.keys()) > 1

def _mpd_get_function(element, attribute_name, default=None):
    return getattr(element, attribute_name, None)

class ManifestIterator(BaseManifestIterator):

    _field_matcher = FieldMatcher(get_function=_mpd_get_function)

    _recurse_keys = ["periods", "adaptationSets", "representations"]

    def _schema(self):

        return Schema(
            Or(
                {"plugin_config": self._plugin_config_schema},
                {
                    # 'periods' is mandatory. After this, you either have the
                    #   specific plugin configuration or (possibly multiple)
                    #   couples of <key> : <regular expression> couples, followed
                    #   by the 'adaptationSets' keyword.
                    "periods": Or(
                        {"plugin_config": self._plugin_config_schema},
                        [
                            And(
                                {
                                    str: lambda s: re.compile(s),
                                    Optional(
                                        "plugin_config"
                                    ): self._plugin_config_schema,
                                    Optional("adaptationSets"): Or(
                                        {"plugin_config": self._plugin_config_schema},
                                        [
                                            And(
                                                {
                                                    str: lambda s: re.compile(s),
                                                    Optional(
                                                        "plugin_config"
                                                    ): self._plugin_config_schema,
                                                    Optional("representations"): Or(
                                                        {
                                                            "plugin_config": self._plugin_config_schema
                                                        },
                                                        [
                                                            {
                                                                str: lambda s: re.compile(
                                                                    s
                                                                ),
                                                                "plugin_config": self._plugin_config_schema,
                                                            }
                                                        ],
                                                    ),
                                                },
                                                _is_config_dict_not_empty,
                                            )
                                        ],
                                    ),
                                },
                                _is_config_dict_not_empty,
                            )
                        ],
                    )
                },
            )
        )
